get_pytype_name

Function get_pytype_name 

pub fn get_pytype_name<'py>(
    obj: &Bound<'py, PyAny>,
) -> PyResult<Bound<'py, PyString>>
Gets the type name for the given Python obj.

Errors

Returns a error if accessing the type name fails.